require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscomconsolesetup',
  dscmeta_resource_friendly_name: 'xSCOMConsoleSetup',
  dscmeta_resource_name: 'MSFT_xSCOMConsoleSetup',
  dscmeta_module_name: 'xSCOM',
  dscmeta_module_version: '1.3.3.0',
  docs: 'The DSC xSCOMConsoleSetup resource type.
         Automatically generated from version 1.3.3.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_sourcepath: {
      type: 'String',
      desc: 'UNC path to the root of the source files for installation.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_installpath: {
      type: 'Optional[String]',
      desc: 'Installation path for the software.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sendceipreports: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to the Customer Experience Improvement Program (CEIP). 1: Opt in to CEIP.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sendodrreports: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to sending operational data reports. 1: opt in to sending operational data reports.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'An enumerated value that describes if the OM Console is expected to be installed on the machine. Present {default}   Absent    ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_setupcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential to be used to perform the installation.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_usemicrosoftupdate: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to Microsoft Update. 1: Opt in to Microsoft Update.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_enableerrorreporting: {
      type: "Optional[Enum['Never', 'Queued', 'Always']]",
      desc: 'Never: Do not opt in to sending automatic error reports. Queued: Opt in to sending error reports, but queue the reports for review before sending. Always: Opt in to automatically send error reports.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcefolder: {
      type: 'Optional[String]',
      desc: 'Folder within the source path containing the source files for installation.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
