require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscommanagementpack',
  dscmeta_resource_friendly_name: 'xSCOMManagementPack',
  dscmeta_resource_name: 'MSFT_xSCOMManagementPack',
  dscmeta_module_name: 'xSCOM',
  dscmeta_module_version: '1.3.3.0',
  docs: 'The DSC xSCOMManagementPack resource type.
         Automatically generated from version 1.3.3.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_sourcepath: {
      type: 'Optional[String]',
      desc: 'UNC path to the root of the source files for installation, if omitted the Operations Manager installation folder will be used.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sourcefile: {
      type: 'String',
      desc: 'Name of the file in the source folder for the Management Pack.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the Management Pack.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minversion: {
      type: 'Optional[String]',
      desc: 'Minimum version of the Management Pack, overridden by Version if both set.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_version: {
      type: 'Optional[String]',
      desc: 'Specific version of the Management Pack, overrides MinVersion if both set.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcefolder: {
      type: 'String',
      desc: 'Folder within the source path containing the source files for installation.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scomadmincredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential with admin permissions to Operations Manager.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
