require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscommanagementserversetup',
  dscmeta_resource_friendly_name: 'xSCOMManagementServerSetup',
  dscmeta_resource_name: 'MSFT_xSCOMManagementServerSetup',
  dscmeta_module_name: 'xSCOM',
  dscmeta_module_version: '1.3.3.0',
  docs: 'The DSC xSCOMManagementServerSetup resource type.
         Automatically generated from version 1.3.3.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_usemicrosoftupdate: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to Microsoft Update. 1: Opt in to Microsoft Update.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_datareaderusername: {
      type: 'Optional[String]',
      desc: 'Output username of the data reader account.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_productkey: {
      type: 'Optional[String]',
      desc: 'Product key for licensed installations.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableerrorreporting: {
      type: "Optional[Enum['Never', 'Queued', 'Always']]",
      desc: 'Never: Do not opt in to sending automatic error reports. Queued: Opt in to sending error reports, but queue the reports for review before sending. Always: Opt in to automatically send error reports.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_datawriter: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The domain and user name of the data Writer account.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_actionaccount: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The domain and user name of the Management server action account.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_setupcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential to be used to perform the installation.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_databasesize: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'The size in MB of the Operational database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'Optional[String]',
      desc: 'The name of the Operational database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_actionaccountusername: {
      type: 'Optional[String]',
      desc: 'Output username of the Management server action account.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcefolder: {
      type: 'Optional[String]',
      desc: 'Folder within the source path containing the source files for installation.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sendceipreports: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to the Customer Experience Improvement Program (CEIP). 1: Opt in to CEIP.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sourcepath: {
      type: 'String',
      desc: 'UNC path to the root of the source files for installation.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dwdatabasesize: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'The size in MB of the data warehouse database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_sqlserverinstance: {
      type: 'String',
      desc: 'The SQL server and instance.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dwdatabasename: {
      type: 'Optional[String]',
      desc: 'The name of the data warehouse database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'An enumerated value that describes if the OM management server is expected to be installed on the machine. Present {default}   Absent    ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_managementserviceport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Change the Management Server port on install.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_sendodrreports: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to sending operational data reports. 1: opt in to sending operational data reports.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_datawriterusername: {
      type: 'Optional[String]',
      desc: 'Output username of the data writer account.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_installpath: {
      type: 'Optional[String]',
      desc: 'Installation path for the software.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_managementgroupname: {
      type: 'String',
      desc: 'The name of the management group.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_datareader: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The domain and user name of the data reader account.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_dasaccountusername: {
      type: 'Optional[String]',
      desc: 'Output username of the Data Access service account.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_firstmanagementserver: {
      type: 'Boolean',
      desc: 'Is this the first Management Server?',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_dasaccount: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The domain and user name of the Data Access service account.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_dwsqlserverinstance: {
      type: 'String',
      desc: 'The data warehouse server and instance.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
